from setuptools import setup

setup(name='gnb_distributions',
      version='0.1',
      description='Gaussian and Bionomial distributions',
      author="Daniel Chris Daniil",
      author_email="dannyd1997@g.ucla.edu",
      packages=['gnb_distributions'],
      zip_safe=False)
